==> algolia_client_recommend-0.1.2.tar.gz: lib/algolia_client_recommend.dart <==
// A sub-package of the AlgoliaSearch library, offering recommend-specific functionalities for enhanced search and discovery in Dart/Flutter apps.
library algolia_client_recommend;

export 'package:algolia_client_core/algolia_client_core.dart';

export 'src/api/recommend_client.dart';

export 'src/model/advanced_syntax_features.dart';
export 'src/model/alternatives_as_exact.dart';
export 'src/model/anchoring.dart';
export 'src/model/around_precision_from_value_inner.dart';
export 'src/model/around_radius_all.dart';
export 'src/model/automatic_facet_filter.dart';
export 'src/model/base_recommend_request.dart';
export 'src/model/base_recommendation_request.dart';
export 'src/model/base_search_params.dart';
export 'src/model/base_search_params_without_query.dart';
export 'src/model/base_search_response.dart';
export 'src/model/base_search_response_redirect.dart';
export 'src/model/base_trending_request.dart';
export 'src/model/condition.dart';
export 'src/model/consequence.dart';
export 'src/model/consequence_hide.dart';
export 'src/model/consequence_params.dart';
export 'src/model/consequence_query_object.dart';
export 'src/model/deleted_at_response.dart';
export 'src/model/edit.dart';
export 'src/model/edit_type.dart';
export 'src/model/error_base.dart';
export 'src/model/exact_on_single_word_query.dart';
export 'src/model/facet_ordering.dart';
export 'src/model/facets.dart';
export 'src/model/facets_stats.dart';
export 'src/model/get_recommend_task_response.dart';
export 'src/model/get_recommendations_params.dart';
export 'src/model/get_recommendations_response.dart';
export 'src/model/highlight_result_option.dart';
export 'src/model/index_settings_as_search_params.dart';
export 'src/model/index_settings_as_search_params_semantic_search.dart';
export 'src/model/match_level.dart';
export 'src/model/matched_geo_location.dart';
export 'src/model/mode.dart';
export 'src/model/params.dart';
export 'src/model/personalization.dart';
export 'src/model/promote_object_id.dart';
export 'src/model/promote_object_ids.dart';
export 'src/model/query_type.dart';
export 'src/model/ranking_info.dart';
export 'src/model/recommend_hit.dart';
export 'src/model/recommend_hits.dart';
export 'src/model/recommend_models.dart';
export 'src/model/recommendation_models.dart';
export 'src/model/recommendation_request.dart';
export 'src/model/recommendations_response.dart';
export 'src/model/redirect_rule_index_metadata.dart';
export 'src/model/redirect_rule_index_metadata_data.dart';
export 'src/model/remove_words_if_no_results.dart';
export 'src/model/rendering_content.dart';
export 'src/model/rule_response.dart';
export 'src/model/rule_response_metadata.dart';
export 'src/model/search_params_object.dart';
export 'src/model/search_params_query.dart';
export 'src/model/search_recommend_rules_params.dart';
export 'src/model/search_recommend_rules_response.dart';
export 'src/model/snippet_result_option.dart';
export 'src/model/sort_remaining_by.dart';
export 'src/model/task_status.dart';
export 'src/model/trending_models.dart';
export 'src/model/trending_request.dart';
export 'src/model/typo_tolerance_enum.dart';
export 'src/model/value.dart';

export 'src/extension.dart';

==> algolia_client_recommend-1.4.0.tar.gz: lib/algolia_client_recommend.dart <==
// A sub-package of the AlgoliaSearch library, offering recommend-specific functionalities for enhanced search and discovery in Dart/Flutter apps.
library algolia_client_recommend;

export 'package:algolia_client_core/algolia_client_core.dart';

export 'src/api/recommend_client.dart';

export 'src/model/advanced_syntax_features.dart';
export 'src/model/alternatives_as_exact.dart';
export 'src/model/anchoring.dart';
export 'src/model/around_precision_from_value_inner.dart';
export 'src/model/around_radius_all.dart';
export 'src/model/automatic_facet_filter.dart';
export 'src/model/base_recommend_request.dart';
export 'src/model/base_recommendations_query.dart';
export 'src/model/base_recommended_for_you_query.dart';
export 'src/model/base_recommended_for_you_query_parameters.dart';
export 'src/model/base_search_params.dart';
export 'src/model/base_search_params_without_query.dart';
export 'src/model/base_search_response.dart';
export 'src/model/base_trending_facets_query.dart';
export 'src/model/base_trending_items_query.dart';
export 'src/model/condition.dart';
export 'src/model/consequence.dart';
export 'src/model/consequence_hide.dart';
export 'src/model/consequence_params.dart';
export 'src/model/consequence_query_object.dart';
export 'src/model/deleted_at_response.dart';
export 'src/model/edit.dart';
export 'src/model/edit_type.dart';
export 'src/model/error_base.dart';
export 'src/model/exact_on_single_word_query.dart';
export 'src/model/exhaustive.dart';
export 'src/model/facet_ordering.dart';
export 'src/model/facets.dart';
export 'src/model/facets_stats.dart';
export 'src/model/get_recommend_task_response.dart';
export 'src/model/get_recommendations_params.dart';
export 'src/model/get_recommendations_response.dart';
export 'src/model/highlight_result_option.dart';
export 'src/model/index_settings_as_search_params.dart';
export 'src/model/match_level.dart';
export 'src/model/matched_geo_location.dart';
export 'src/model/mode.dart';
export 'src/model/params.dart';
export 'src/model/personalization.dart';
export 'src/model/promote_object_id.dart';
export 'src/model/promote_object_ids.dart';
export 'src/model/query_type.dart';
export 'src/model/ranking_info.dart';
export 'src/model/recommend_hit.dart';
export 'src/model/recommend_models.dart';
export 'src/model/recommendation_models.dart';
export 'src/model/recommendations_hits.dart';
export 'src/model/recommendations_query.dart';
export 'src/model/recommendations_results.dart';
export 'src/model/recommended_for_you_model.dart';
export 'src/model/recommended_for_you_query.dart';
export 'src/model/recommended_for_you_query_parameters.dart';
export 'src/model/redirect.dart';
export 'src/model/redirect_rule_index_metadata.dart';
export 'src/model/redirect_rule_index_metadata_data.dart';
export 'src/model/remove_words_if_no_results.dart';
export 'src/model/rendering_content.dart';
export 'src/model/rule_response.dart';
export 'src/model/rule_response_metadata.dart';
export 'src/model/search_params_object.dart';
export 'src/model/search_params_query.dart';
export 'src/model/search_recommend_rules_params.dart';
export 'src/model/search_recommend_rules_response.dart';
export 'src/model/semantic_search.dart';
export 'src/model/snippet_result_option.dart';
export 'src/model/sort_remaining_by.dart';
export 'src/model/task_status.dart';
export 'src/model/trending_facet_hit.dart';
export 'src/model/trending_facets_model.dart';
export 'src/model/trending_facets_query.dart';
export 'src/model/trending_items_model.dart';
export 'src/model/trending_items_query.dart';
export 'src/model/typo_tolerance_enum.dart';
export 'src/model/value.dart';

export 'src/extension.dart';
